@@ -35,7 +35,33 @@ def _download(args):
     
     return urllib.urlopen(base + args).read()
 
-def _get_lyrics(page_title):
+def _get_page_titles(artist, title):
+    """
+        Returns a list of available page titles
+    """
+    
+    args = {"action": "query",
+        "list": "search",
+        "srsearch": artist + " " + title,
+        "format": "json",
+        }
+    
+    titles = []
+    content = json.loads(_download(args))
+    for title in content["query"]["search"]:
+        titles.append(title["title"])
+    
+    return titles
+
+def _get_lyrics(artist, title):
+    
+    titles = _get_page_titles(artist, title)
+    
+    if titles:
+        page_title = titles[0]
+    else:
+        return
+    
     args = {"action": "query",
         "prop": "revisions",
         "rvprop": "content",
@@ -76,11 +102,12 @@ def get_lyrics(artist, title, cache_dir=None):
             fp = open(path)
             return json.load(fp)["lyrics"].strip()
         
-    lyrics = _get_lyrics("%s:%s" %(artist.title(), title.title()))
+    lyrics = _get_lyrics(artist, title)
     
-    if path and lyrics.strip():
+    if path and lyrics:
         fp = open(path, "w")
         json.dump({"time": time.time(), "artist": artist, "title": title,
                     "source": "lyricwiki", "lyrics": lyrics }, fp, indent=4)
+        fp.close()
     
-    return lyrics.strip()
+    return lyrics
